#include "f81866a.h"

#include "stdio.h"
#include "stdlib.h"

#include "string.h"
#include "stdbool.h"

bool SILENT = false;

void print_message(char *message) {
  if (!SILENT) {
    printf("%s", message);
  }
}

int main(int argc, char *argv[]) {
  int i = 0;
  bool loop, disable = false;
  short time = 10;

  for (i = 0; i < argc; i++) {
    if (!strcmp(argv[i], "--loop") || !strcmp(argv[i], "-l")) {
      loop = true;
    }
    if (!strcmp(argv[i], "--time") || !strcmp(argv[i], "-t")) {
      if ((i + 1 < argc) && (atoi(argv[i+1]))) {
	time = atoi(argv[i+1]);
	i++;
      }
    }
    if (!strcmp(argv[i], "--silent") || !strcmp(argv[i], "-s")) {
      SILENT = true;
    }
    if (!strcmp(argv[i], "--off")) {
      disable = true;
    }
  }

  //test for permission to open
  if (!CheckLpcPermission()) {
    print_message("Error opening LPC port. Check permissions and try again.\n");
    return -1;
  }
  
  if (disable) {
    DisableWatchdog();
    print_message("Watchdog disabled.\n");
    return 0;
  }

  if (!SILENT)
    printf("Setting watchdog timer for %d seconds.\n", time);
  if (loop) {
    print_message("Looping continuously until killed.\n");
  } else {
    print_message("Will reboot unless run again before timeout.\n");
  }

  EnableWatchdog(time);
  while( loop ) {
    SetWatchdogTime(time);
#ifdef __MINGW32__
    Sleep((float)time / 500);
#else
    usleep((float)time / 500000);
#endif
  }
  return 0;
}
  
